import os
import signal
import sys

from PyQt5.QtWidgets import QApplication
from PyQt5.QtGui import QIcon

from .tools.camposkop_tool import CamposkopTool
from .services.e_log_service import ELogService
from .services.concurrency_service import ConcurrencyService
from .services.io_service import IOService
from .materials.e_log_data import ELogData
from .materials.image_data import ImageData


def startup_application():
    signal.signal(signal.SIGINT, signal.SIG_DFL)  # handles Ctrl-C interrupts via default signal (core dump and exit)

    application = QApplication([CamposkopTool.APPLICATION_NAME])
    application.setWindowIcon(QIcon(os.path.dirname(os.path.abspath(__file__)) + "/resources/camposkop.png"))

    e_log_data = ELogData(printer="fl1_camplog")
    image_data = ImageData(camera_address_1="FLASH.FEL/FBL3.CAM/CMOS1/IMAGE_EXT",
                           camera_address_2="FLASH.FEL/FBL3.CAM/CMOS2/IMAGE_EXT")

    camposkop_tool = CamposkopTool(ELogService(e_log_data), ConcurrencyService(), IOService(image_data))
    camposkop_tool.show_window()

    sys.excepthook = camposkop_tool.exception_handler
    sys.exit(application.exec())
