from PyQt5.QtWidgets import QDialog, QLineEdit, QComboBox, QTextEdit, QPushButton, QVBoxLayout, QHBoxLayout, QSizePolicy


class PrintToolUi(QDialog):

    FATAL = "FATAL"

    _SEVERITY_LIST = ["NONE", FATAL, "ERROR", "FIXED", "TODO", "DONE", "WARN", "INFO", "IDEA", "DOCU", "MEASURE",
                      "STATISTICS", "WOW"]

    def __init__(self, window_title, default_author):
        super().__init__()
        self.setWindowTitle(window_title)
        self._main_layout = QVBoxLayout()
        self._author_line_edit = QLineEdit(default_author)
        self._title_line_edit = QLineEdit()
        self._severity_combo_box = QComboBox()
        self._text_edit = QTextEdit()
        self._print_button = self._get_push_button_with("Print")
        self._cancel_button = self._get_push_button_with("Cancel")
        self._create_layout()

    @staticmethod
    def _get_push_button_with(label):
        push_button = QPushButton(label)
        push_button.setAutoDefault(False)
        return push_button

    def _create_layout(self):
        self._create_main_layout()
        self._create_info_layout()
        self._create_text_field_layout()
        self._create_buttons_layout()

    def _create_main_layout(self):
        self.setLayout(self._main_layout)
        self.setModal(True)

    def _create_info_layout(self):
        self._author_line_edit.setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Preferred)
        info_layout = QHBoxLayout()
        info_layout.addWidget(self._author_line_edit)
        info_layout.addWidget(self._title_line_edit)
        info_layout.addWidget(self._severity_combo_box)
        self._severity_combo_box.addItems(self._SEVERITY_LIST)
        self._main_layout.addLayout(info_layout)

    def _create_text_field_layout(self):
        self._text_edit.setFocus()
        self._main_layout.addWidget(self._text_edit)

    def _create_buttons_layout(self):
        buttons_layout = QHBoxLayout()
        buttons_layout.addWidget(self._print_button)
        buttons_layout.addWidget(self._cancel_button)
        self._main_layout.addLayout(buttons_layout)

    @property
    def author_line_edit(self):
        return self._author_line_edit

    @property
    def title_line_edit(self):
        return self._title_line_edit

    @property
    def severity_combo_box(self):
        return self._severity_combo_box

    @property
    def text_edit(self):
        return self._text_edit

    @property
    def print_button(self):
        return self._print_button

    @property
    def cancel_button(self):
        return self._cancel_button

    def show_window(self):
        self.show()
        self.setMinimumSize(self.width(), self.height())
